<?xml version="1.0" encoding="UTF-8" ?>
<!-- This file handles variable definitions -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
  <xsl:variable name="ST_ATTRIBUTE_CATEGORIES">DS_ATTRIBUTE_CATEGORIES</xsl:variable>
  <xsl:variable name="ST_ATTRIBUTES">DS_ATTRIBUTES</xsl:variable>

  <!-- Staging Field names -->
  <xsl:variable name="category_name_field">category_name</xsl:variable>
  <xsl:variable name="attribute_name_field">attribute_name</xsl:variable>
  <xsl:variable name="attribute_category_key_field">attribute_category_key</xsl:variable>

  <!-- Attribute Category .. Table Level -->
  <xsl:template match="attribute_category">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_ATTRIBUTE_CATEGORIES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncCustomAttributeCategoryService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncCustomAttributeCategoryService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_ATTRIBUTE_CATEGORIES" />
      </xsl:call-template>
    </bean>
  </xsl:template>
  
  <!-- Attributes .. Table Level -->
  <xsl:template match="attribute">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_ATTRIBUTES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncCustomAttributeService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncCustomAttributeService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_ATTRIBUTES" />
      </xsl:call-template>
    </bean>
  </xsl:template>

  <!-- Attribute Category .. Field Level -->
  <xsl:template match="category_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">name</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <!-- Attribute .. Field Level -->    
  <xsl:template match="attribute_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">name</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="attribute_category_key">
    <xsl:call-template name="call_fields">
			<xsl:with-param name="synchronizer_class" select="$enterprise_attribute_category_field_synchronizer"/>
      <xsl:with-param name="model_property_name">category</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
